@@ -55,6 +55,7 @@ struct DownloadConfig
     bool bIgnoreDLCCount;
     bool bDuplicateHandler;
     bool bGalaxyDependencies;
+    bool bGalaxyDeleteOrphans;
 };
 
 struct gameSpecificConfig
@@ -197,12 +198,6 @@ struct CurlConfig
     long int iLowSpeedTimeoutRate;
 };
 
-struct GogAPIConfig
-{
-    std::string sToken;
-    std::string sSecret;
-};
-
 class Config
 {
     public:
@@ -210,8 +205,7 @@ class Config
         virtual ~Config() {};
 
         // Booleans
-        bool bLoginHTTP;
-        bool bLoginAPI;
+        bool bLogin;
         bool bSaveConfig;
         bool bResetConfig;
 
@@ -280,8 +274,6 @@ class Config
         std::string sEmail;
         std::string sPassword;
 
-        GogAPIConfig apiConf;
-
         // Lists
         Blacklist blacklist;
         Blacklist ignorelist;
@@ -291,6 +283,7 @@ class Config
         // Integers
         int iRetries;
         unsigned int iThreads;
+        unsigned int iInfoThreads;
         int iWait;
         size_t iChunkSize;
         int iProgressInterval;
