@@ -22,7 +22,6 @@
 #endif
 
 #include "config.h"
-#include "api.h"
 #include "progressbar.h"
 #include "website.h"
 #include "threadsafequeue.h"
@@ -69,19 +68,28 @@ struct ChunkMemoryStruct
 
 typedef struct
 {
-	std::string filepath;
-	off_t comp_size;
-	off_t uncomp_size;
-	off_t start_offset_zip;
-	off_t start_offset_mojosetup;
-	off_t end_offset;
-	uint16_t file_attributes;
-	uint32_t crc32;
-	time_t timestamp;
+    std::string filepath;
+    off_t comp_size;
+    off_t uncomp_size;
+    off_t start_offset_zip;
+    off_t start_offset_mojosetup;
+    off_t end_offset;
+    uint16_t file_attributes;
+    uint32_t crc32;
+    time_t timestamp;
 
-	std::string installer_url;
+    std::string installer_url;
+
+    // For split file handling
+    bool isSplitFile = false;
+    std::string splitFileBasePath;
+    std::string splitFilePartExt;
+    off_t splitFileStartOffset;
+    off_t splitFileEndOffset;
 } zipFileEntry;
 
+typedef std::map<std::string,std::vector<zipFileEntry>> splitFilesMap;
+
 class Downloader
 {
     public:
@@ -120,11 +128,10 @@ class Downloader
         CURLcode beginDownload();
         std::string getResponse(const std::string& url);
         std::string getLocalFileHash(const std::string& filepath, const std::string& gamename = std::string());
-        std::string getRemoteFileHash(const std::string& gamename, const std::string& id);
+        std::string getRemoteFileHash(const gameFile& gf);
         int loadGameDetailsCache();
         int saveGameDetailsCache();
         std::vector<gameDetails> getGameDetailsFromJsonNode(Json::Value root, const int& recursion_level = 0);
-        static std::vector<gameFile> getExtrasFromJSON(const Json::Value& json, const std::string& gamename, const Config& config);
         static std::string getSerialsFromJSON(const Json::Value& json);
         void saveSerials(const std::string& serials, const std::string& filepath);
         static std::string getChangelogFromJSON(const Json::Value& json);
@@ -142,13 +149,14 @@ class Downloader
         std::vector<std::string> galaxyGetOrphanedFiles(const std::vector<galaxyDepotItem>& items, const std::string& install_path);
         static void processGalaxyDownloadQueue(const std::string& install_path, Config conf, const unsigned int& tid);
         void galaxyInstallGame_MojoSetupHack(const std::string& product_id);
+        void galaxyInstallGame_MojoSetupHack_CombineSplitFiles(const splitFilesMap& mSplitFiles, const bool& bAppendtoFirst = false);
         static void processGalaxyDownloadQueue_MojoSetupHack(Config conf, const unsigned int& tid);
         int mojoSetupGetFileVector(const gameFile& gf, std::vector<zipFileEntry>& vFiles);
         std::string getGalaxyInstallDirectory(galaxyAPI *galaxyHandle, const Json::Value& manifest);
         bool galaxySelectProductIdHelper(const std::string& product_id, std::string& selected_product);
+        std::vector<galaxyDepotItem> galaxyGetDepotItemVectorFromJson(const Json::Value& json, const unsigned int& iGalaxyArch = GlobalConstants::ARCH_X64);
 
         Website *gogWebsite;
-        API *gogAPI;
         galaxyAPI *gogGalaxy;
         std::vector<gameItem> gameItems;
         std::vector<gameDetails> games;
