@@ -167,7 +167,6 @@ int main(int argc, char *argv[])
         bool bNoRemoteXML = false;
         bool bNoSubDirectories = false;
         bool bNoPlatformDetection = false;
-        bool bLogin = false;
         bool bNoGalaxyDependencies = false;
         std::string sInstallerPlatform;
         std::string sInstallerLanguage;
@@ -182,7 +181,7 @@ int main(int argc, char *argv[])
         options_cli_no_cfg.add_options()
             ("help,h", "Print help message")
             ("version", "Print version information")
-            ("login", bpo::value<bool>(&bLogin)->zero_tokens()->default_value(false), "Login")
+            ("login", bpo::value<bool>(&Globals::globalConfig.bLogin)->zero_tokens()->default_value(false), "Login")
             ("list", bpo::value<bool>(&Globals::globalConfig.bList)->zero_tokens()->default_value(false), "List games")
             ("list-details", bpo::value<bool>(&Globals::globalConfig.bListDetails)->zero_tokens()->default_value(false), "List games with detailed info")
             ("download", bpo::value<bool>(&Globals::globalConfig.bDownload)->zero_tokens()->default_value(false), "Download")
@@ -202,8 +201,6 @@ int main(int argc, char *argv[])
             ("download-file", bpo::value<std::string>(&Globals::globalConfig.sFileIdString)->default_value(""), "Download files using fileid\n\nFormat:\n\"gamename/fileid\"\nor: \"gogdownloader://gamename/fileid\"\n\nMultiple files:\n\"gamename1/fileid1,gamename2/fileid2\"\nor: \"gogdownloader://gamename1/fileid1,gamename2/fileid2\"\n\nThis option ignores all subdir options. The files are downloaded to directory specified with --directory option.")
             ("output-file,o", bpo::value<std::string>(&Globals::globalConfig.sOutputFilename)->default_value(""), "Set filename of file downloaded with --download-file.")
             ("wishlist", bpo::value<bool>(&Globals::globalConfig.bShowWishlist)->zero_tokens()->default_value(false), "Show wishlist")
-            ("login-api", bpo::value<bool>(&Globals::globalConfig.bLoginAPI)->zero_tokens()->default_value(false), "Login (API only)")
-            ("login-website", bpo::value<bool>(&Globals::globalConfig.bLoginHTTP)->zero_tokens()->default_value(false), "Login (website only)")
             ("cacert", bpo::value<std::string>(&Globals::globalConfig.curlConf.sCACertPath)->default_value(""), "Path to CA certificate bundle in PEM format")
             ("respect-umask", bpo::value<bool>(&Globals::globalConfig.bRespectUmask)->zero_tokens()->default_value(false), "Do not adjust permissions of sensitive files")
             ("user-agent", bpo::value<std::string>(&Globals::globalConfig.curlConf.sUserAgent)->default_value(DEFAULT_USER_AGENT), "Set user agent")
@@ -245,17 +242,13 @@ int main(int argc, char *argv[])
             ("automatic-xml-creation", bpo::value<bool>(&Globals::globalConfig.dlConf.bAutomaticXMLCreation)->zero_tokens()->default_value(false), "Automatically create XML data after download has completed")
             ("save-changelogs", bpo::value<bool>(&Globals::globalConfig.dlConf.bSaveChangelogs)->zero_tokens()->default_value(false), "Save changelogs when downloading")
             ("threads", bpo::value<unsigned int>(&Globals::globalConfig.iThreads)->default_value(4), "Number of download threads")
+            ("info-threads", bpo::value<unsigned int>(&Globals::globalConfig.iInfoThreads)->default_value(4), "Number of threads for getting product info")
             ("dlc-list", bpo::value<std::string>(&Globals::globalConfig.sGameHasDLCList)->default_value("https://raw.githubusercontent.com/Sude-/lgogdownloader-lists/master/game_has_dlc.txt"), "Set URL for list of games that have DLC")
             ("progress-interval", bpo::value<int>(&Globals::globalConfig.iProgressInterval)->default_value(100), "Set interval for progress bar update (milliseconds)\nValue must be between 1 and 10000")
             ("lowspeed-timeout", bpo::value<long int>(&Globals::globalConfig.curlConf.iLowSpeedTimeout)->default_value(30), "Set time in number seconds that the transfer speed should be below the rate set with --lowspeed-rate for it to considered too slow and aborted")
             ("lowspeed-rate", bpo::value<long int>(&Globals::globalConfig.curlConf.iLowSpeedTimeoutRate)->default_value(200), "Set average transfer speed in bytes per second that the transfer should be below during time specified with --lowspeed-timeout for it to be considered too slow and aborted")
             ("include-hidden-products", bpo::value<bool>(&Globals::globalConfig.bIncludeHiddenProducts)->zero_tokens()->default_value(false), "Include games that have been set hidden in account page")
         ;
-        // Options read from config file
-        options_cfg_only.add_options()
-            ("token", bpo::value<std::string>(&Globals::globalConfig.apiConf.sToken)->default_value(""), "oauth token")
-            ("secret", bpo::value<std::string>(&Globals::globalConfig.apiConf.sSecret)->default_value(""), "oauth secret")
-        ;
 
         options_cli_no_cfg_hidden.add_options()
             ("login-email", bpo::value<std::string>(&Globals::globalConfig.sEmail)->default_value(""), "login email")
@@ -271,6 +264,7 @@ int main(int argc, char *argv[])
             ("galaxy-no-dependencies", bpo::value<bool>(&bNoGalaxyDependencies)->zero_tokens()->default_value(false), "Don't download dependencies during --galaxy-install")
             ("subdir-galaxy-install", bpo::value<std::string>(&Globals::globalConfig.dirConf.sGalaxyInstallSubdir)->default_value("%install_dir%"), galaxy_install_subdir_text.c_str())
             ("galaxy-cdn-priority", bpo::value<std::string>(&sGalaxyCDN)->default_value("edgecast,highwinds,gog_cdn"), galaxy_cdn_priority_text.c_str())
+            ("galaxy-delete-orphans", bpo::value<bool>(&Globals::globalConfig.dlConf.bGalaxyDeleteOrphans)->zero_tokens()->default_value(false), "Delete orphaned files during --galaxy-install")
         ;
 
         options_cli_all.add(options_cli_no_cfg).add(options_cli_cfg).add(options_cli_experimental);
@@ -409,7 +403,7 @@ int main(int argc, char *argv[])
             }
         }
 
-        if (bLogin || Globals::globalConfig.bLoginAPI || Globals::globalConfig.bLoginHTTP)
+        if (Globals::globalConfig.bLogin)
         {
             std::string login_conf = Globals::globalConfig.sConfigDirectory + "/login.txt";
             if (boost::filesystem::exists(login_conf))
@@ -490,12 +484,6 @@ int main(int argc, char *argv[])
             return 1;
         }
 
-        if (bLogin)
-        {
-            Globals::globalConfig.bLoginAPI = true;
-            Globals::globalConfig.bLoginHTTP = true;
-        }
-
         if (Globals::globalConfig.sXMLFile == "automatic")
             Globals::globalConfig.dlConf.bAutomaticXMLCreation = true;
 
@@ -604,19 +592,13 @@ int main(int argc, char *argv[])
     ssl_thread_setup();
     curl_global_init(CURL_GLOBAL_ALL);
 
-    if (Globals::globalConfig.bLoginAPI)
-    {
-        Globals::globalConfig.apiConf.sToken = "";
-        Globals::globalConfig.apiConf.sSecret = "";
-    }
-
     Downloader downloader;
 
     int iLoginTries = 0;
     bool bLoginOK = false;
 
     // Login because --login, --login-api or --login-website was used
-    if (Globals::globalConfig.bLoginAPI || Globals::globalConfig.bLoginHTTP)
+    if (Globals::globalConfig.bLogin)
         bLoginOK = downloader.login();
 
     bool bIsLoggedin = downloader.isLoggedIn();
@@ -649,11 +631,6 @@ int main(int argc, char *argv[])
 
     if (Globals::globalConfig.bSaveConfig || bLoginOK)
     {
-        if (bLoginOK)
-        {
-            set_vm_value(vm, "token", Globals::globalConfig.apiConf.sToken);
-            set_vm_value(vm, "secret", Globals::globalConfig.apiConf.sSecret);
-        }
         std::ofstream ofs(Globals::globalConfig.sConfigFilePath.c_str());
         if (ofs)
         {
@@ -721,11 +698,6 @@ int main(int argc, char *argv[])
         std::ofstream ofs(Globals::globalConfig.sConfigFilePath.c_str());
         if (ofs)
         {
-            if (!Globals::globalConfig.apiConf.sToken.empty() && !Globals::globalConfig.apiConf.sSecret.empty())
-            {
-                ofs << "token = " << Globals::globalConfig.apiConf.sToken << std::endl;
-                ofs << "secret = " << Globals::globalConfig.apiConf.sSecret << std::endl;
-            }
             ofs.close();
             if (!Globals::globalConfig.bRespectUmask)
                 Util::setFilePermissions(Globals::globalConfig.sConfigFilePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
@@ -802,7 +774,7 @@ int main(int argc, char *argv[])
     }
     else
     {
-        if (!(Globals::globalConfig.bLoginAPI || Globals::globalConfig.bLoginHTTP))
+        if (!Globals::globalConfig.bLogin)
         {
             // Show help message
             std::cerr   << Globals::globalConfig.sVersionString << std::endl
